==> haskell-invariant-0.5.3-22-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: invariant
version: 0.5.3
id: invariant-0.5.3-9rqqo5L116JKCpzEKRkmyy
key: invariant-0.5.3-9rqqo5L116JKCpzEKRkmyy
license: BSD-2-Clause
maintainer: Nicolas Frisby <nicolas.frisby@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Nicolas Frisby <nicolas.frisby@gmail.com>
homepage: https://github.com/nfrisby/invariant-functors
synopsis: Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).
    .
    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":
    .
    <http://comonad.com/reader/2008/rotten-bananas/>
category: Control, Data
abi: beee4f5e5664f447f45bcca1e49bf09b
exposed: True
exposed-modules:
    Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules: Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs: /usr/lib/ghc-8.6.5/site-local/invariant-0.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/invariant-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/invariant-0.5.3
hs-libraries: HSinvariant-0.5.3-9rqqo5L116JKCpzEKRkmyy
depends:
    StateVar-1.1.1.1-2ewTKofpCGhC2np5dyFIaR array-0.5.3.0 base-4.12.0.0
    bifunctors-5.5.5-AT2O4t2mUeVLY6LKXIjARE
    comonad-5.0.5-CthxCPGmo5h60L0drN1HHd containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ ghc-prim-0.5.3
    profunctors-5.4-FuMvsq9p4l3CSxuI1XIcXh stm-2.5.0.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    th-abstraction-0.3.1.0-KacyXGqFl6k8QB9PBisbIF transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html: /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-invariant-0.5.3-23-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-invariant.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: invariant
version: 0.5.3
id: invariant-0.5.3-JfbIQclZL4568FU6CbZIts
key: invariant-0.5.3-JfbIQclZL4568FU6CbZIts
license: BSD-2-Clause
maintainer: Nicolas Frisby <nicolas.frisby@gmail.com>,
            Ryan Scott <ryan.gl.scott@gmail.com>
author: Nicolas Frisby <nicolas.frisby@gmail.com>
homepage: https://github.com/nfrisby/invariant-functors
synopsis: Haskell98 invariant functors
description:
    Haskell98 invariant functors (also known as exponential functors).
    .
    For more information, see Edward Kmett'\''s article \"Rotten Bananas\":
    .
    <http://comonad.com/reader/2008/rotten-bananas/>
category: Control, Data
abi: 939d51cb6918904523e2f60665392c65
exposed: True
exposed-modules:
    Data.Functor.Invariant Data.Functor.Invariant.TH
hidden-modules: Data.Functor.Invariant.TH.Internal Paths_invariant
import-dirs: /usr/lib/ghc-8.6.5/site-local/invariant-0.5.3
library-dirs: /usr/lib/ghc-8.6.5/site-local/invariant-0.5.3
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/invariant-0.5.3
hs-libraries: HSinvariant-0.5.3-JfbIQclZL4568FU6CbZIts
depends:
    StateVar-1.1.1.1-2ewTKofpCGhC2np5dyFIaR array-0.5.3.0 base-4.12.0.0
    bifunctors-5.5.5-AT2O4t2mUeVLY6LKXIjARE
    comonad-5.0.5-CthxCPGmo5h60L0drN1HHd containers-0.6.0.1
    contravariant-1.5.2-IGTyLqhZC2pCTY0qng5HHQ ghc-prim-0.5.3
    profunctors-5.5-C3RSa0newLDGrqKqFpjE7c stm-2.5.0.0
    tagged-0.8.6-AoE7RQX12AwJxLvAxGYxtP template-haskell-2.14.0.0
    th-abstraction-0.3.1.0-KacyXGqFl6k8QB9PBisbIF transformers-0.5.6.2
    transformers-compat-0.6.5-6PKzEe5EVLXd5Neg4mr6X
    unordered-containers-0.2.10.0-8ZCNQorHEnr2Al0NbBIjXw
haddock-interfaces: /usr/share/doc/haskell-invariant/html/invariant.haddock
haddock-html: /usr/share/doc/haskell-invariant/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
